@@ -13,13 +13,13 @@
 # See the License for the specific language governing permissions and
 # limitations under the License.
 
-from django.core import urlresolvers
+from django import urls
 import mock
 
 from watcher_dashboard import api
 from watcher_dashboard.test import helpers as test
 
-INDEX_URL = urlresolvers.reverse('horizon:admin:goals:index')
+INDEX_URL = urls.reverse('horizon:admin:goals:index')
 DETAILS_VIEW = 'horizon:admin:goals:detail'
 
 
@@ -48,7 +48,7 @@ class GoalsTest(test.BaseAdminViewTests):
         goal_id = goal.uuid
         mock_get.return_value = goal
 
-        DETAILS_URL = urlresolvers.reverse(DETAILS_VIEW, args=[goal_id])
+        DETAILS_URL = urls.reverse(DETAILS_VIEW, args=[goal_id])
         res = self.client.get(DETAILS_URL)
         self.assertTemplateUsed(res, 'infra_optim/goals/details.html')
         goals = res.context['goal']
@@ -60,6 +60,6 @@ class GoalsTest(test.BaseAdminViewTests):
         at_id = at.uuid
         mock_get.side_effect = self.exceptions.watcher
 
-        DETAILS_URL = urlresolvers.reverse(DETAILS_VIEW, args=[at_id])
+        DETAILS_URL = urls.reverse(DETAILS_VIEW, args=[at_id])
         res = self.client.get(DETAILS_URL)
         self.assertRedirectsNoFollow(res, INDEX_URL)
